@@ -291,7 +291,7 @@ class Typer(object):
             self.signature = [re.sub('_.*','',x) for x in list(specifics)]
 
             # Get single effector types
-            single_effector_hmms = self.scores[self.scores['Hmm'].isin(list(specifics))].drop('Hmm', 1)
+            single_effector_hmms = self.scores[self.scores['Hmm'].isin(list(specifics))].drop('Hmm', axis=1)
             single_effector_hmms[single_effector_hmms < 0] = 0
             self.single_effector = list(single_effector_hmms.iloc[:, single_effector_hmms.sum(axis=0).values > 0].columns)
 
